execline: the wait command
Keywords: execline command wait

execline
Software
skarnet.org

# The `wait` program

`wait` waits for a set of children, then executes a program.

## Interface

In an execlineb script:

         wait [ -r ] { [ pids... ] } prog...

- `wait` reads a list of pids in a (possibly empty) block, and unquotes it.
- `wait` waits for every child whose pid is listed in pids.... If pids... is an empty list, it waits for every child process it has.
- `wait` then execs into prog....

## Options

- `-r` : reap mode. Do not pause until a child has exited; only reap all pending zombies. The read block must be empty for that option to be effective.